@@ -8,13 +8,16 @@ function log(msg) {
 $(document).ready(function() {
 	$('#mainContentContainer').height('auto');
 
-	if(!$('#searchSubmitButton').length)
+	var $searchForm = $('#searchForm');
+	if!$searchForm.length)
 		return;
 
+	var $searchTextInput = $('#searchTextInput');
+	$searchTextInput.focus();
+
 	var $kikiAlias = $('#kikiAlias');
 
 	var nonce;
-	var domains_by_id;
 	var domains_by_name;
 
 	function qnonce() {
@@ -25,6 +28,7 @@ $(document).ready(function() {
 		'session': "Your session expired. Please reload the page.",
 		'unknown-alias': "Can't find an alias by this name.",
 		'malformed': "Specified name is malformed.",
+		'too-long': "Specified name is too long.",
 		'stored': "Alias saved.",
 		'empty-name': "Name required.",
 		'empty-domain': "Domain required.",
@@ -77,10 +81,9 @@ $(document).ready(function() {
 		}
 	}
 
-	function domainDisplayName(d) {
-		var names = d.names;
+	function domainDisplayName(names) {
 		var len = names.length;
-		var name = d.name;
+		var name = names[0];
 		if(len > 1) {
 			var sep = ' (';
 			for(var i = 1; i < len; i++) {
@@ -305,7 +308,7 @@ $(document).ready(function() {
 
 		onChange($domain, function() {inputColor($domain, self.alias.domain, self.gooddomain, self.baddomain)});
 
-		var name = this.name = html('input', {type: 'text', name: 'name', 'class': 'name', placeholder: "Name…"});
+		var name = this.name = html('input', {type: 'text', name: 'name', 'class': 'name', placeholder: "Name…", maxlength: 64});
 		var $name = this.$name = $(name);
 
 		onChange($name, function() {inputColor($name, self.alias.name, self.goodname, self.badname)});
@@ -556,7 +559,7 @@ $(document).ready(function() {
 	}
 
 	function zoek() {
-		var q = $('#searchTextInput').val();
+		var q = $searchTextInput.val();
 		window.location.hash = '#' + q;
 		$.ajax({
 			url: 'search',
@@ -581,20 +584,18 @@ $(document).ready(function() {
 	setInterval(getNonce, 1800000);
 
 	function domeinenGeladen(data) {
-		domains_by_id = {};
 		domains_by_name = {};
 		var domains = data.domains;
 		for(var i = 0; i < domains.length; i++) {
-			var domain = domains[i];
-			domains_by_id[domain.id] = domain;
-			domains_by_name[domain.name] = domain;
+			var names = domains[i];
+			domains_by_name[names[0]] = names;
 		}
 
 		var q = window.location.hash;
 		if(q)
 			q = q.substr(1);
 		if(q) {
-			$('#searchTextInput').val(q);
+			$searchTextInput.val(q);
 			zoek();
 		} else {
 			var widget = new AliasWidget();
@@ -613,11 +614,10 @@ $(document).ready(function() {
 		var q = window.location.hash;
 		if(q)
 			q = q.substr(1);
-		var $input = $('#searchTextInput');
-		if(q == $input.val())
+		if(q == $searchTextInput.val())
 			return;
 		if(q) {
-			$input.val(q);
+			$searchTextInput.val(q);
 			zoek();
 		} else {
 			var widget = new AliasWidget();
@@ -625,5 +625,5 @@ $(document).ready(function() {
 		}
 	});
 
-	$('#searchForm').submit(zoek);
+	$searchForm.submit(zoek);
 });
